/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file dynamic.h
 *
 * @type helper
 *
 * @description
 *
 * The dynamic helper maintains dynamic areas for storage with RISC OS 3.5+
 * machines.
 */

#ifndef __rov_dynamic
#define __rov_dynamic


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * Create a dynamic area.
 * @param name the name given in the Task Window.
 * @param size the size of the area to allocate.
 * @param max the maximum size this will be (-1 for as large as possible).
 * @return a handle for the dynamic area
 * @see dynamicarea_destroy()
 * @see dynamicarea_address()
 */
int dynamicarea_create(char *name,
		       int size,
		       int max);

/**
 * Destroy a dynamic area.
 * @param handle the handle of the dynamic area.
 * @see dynamicarea_create()
 */
void dynamicarea_destroy(int handle);

/**
 * Extend a dunamic area.
 * @param handle the handle of the dynamic area.
 * @param new_size the new size of the dynamic area.
 * @return a flag indicating success (non-zero means success).
 * @see dynamicarea_size()
 * @see dynamicarea_create()
 */
int dynamicarea_extend(int handle,
		       int new_size);

/**
 * Get the size of a dynamic area.
 * @param handle the handle of the dynamic area.
 * @return the size of the dynamic area.
 * @see dynamicarea_address()
 */
int dynamicarea_size(int handle);

/**
 * Get the base address of a dynamic area.
 * @param handle the handle of the dynamic area.
 * @return the base address of the dynamic area.
 * @see dynamicarea_size()
 */
void *dynamicarea_address(int handle);


#ifdef __cplusplus
}
#endif

#endif
